@@ -18,6 +18,10 @@ LOG = logging.getLogger(__name__)
 @click.option(
     "--institute", help="Specify the owner of the panel. Defaults to cust000."
 )
+@click.option(
+    "--maintainer",
+    help="Specify the maintainer user id of the panel. Defaults to empty (all users can edit).",
+)
 @click.option(
     "-d", "--date", help="date of gene panel on format 2017-12-24, default is today."
 )
@@ -59,6 +63,7 @@ def panel(
     panel_type,
     panel_id,
     institute,
+    maintainer,
     omim,
     genemap2,
     mim2genes,
@@ -71,41 +76,8 @@ def panel(
     institute = institute or "cust000"
 
     if omim:
-        mim_files = None
-        if genemap2 and mim2genes:
-            mim_files = {
-                "genemap2": list(get_file_handle(genemap2)),
-                "mim2genes": list(get_file_handle(mim2genes)),
-            }
-
-        api_key = api_key or current_app.config.get("OMIM_API_KEY")
-        if not api_key and mim_files is None:
-            LOG.warning("Please provide a omim api key to load the omim gene panel")
-            raise click.Abort()
-        # Check if OMIM-AUTO exists
-        if adapter.gene_panel(panel_id="OMIM-AUTO"):
-            LOG.warning("OMIM-AUTO already exists in database")
-            LOG.info("To create a new version use scout update omim")
-            return
-
-        if not mim_files:
-            try:
-                mim_files = fetch_mim_files(
-                    api_key=api_key, genemap2=True, mim2genes=True
-                )
-            except Exception as err:
-                raise err
-
-        # Here we know that there is no panel loaded
-        try:
-            adapter.load_omim_panel(
-                genemap2_lines=mim_files["genemap2"],
-                mim2gene_lines=mim_files["mim2genes"],
-                institute=institute,
-            )
-        except Exception as err:
-            LOG.error(err)
-            raise click.Abort()
+        _panel_omim(adapter, genemap2, mim2genes, api_key, institute, maintainer)
+        return
 
     if panel_app:
         # try:
@@ -113,8 +85,6 @@ def panel(
         # except Exception as err:
         #     LOG.warning(err)
         #     raise click.Abort()
-
-    if omim or panel_app:
         return
 
     if path is None:
@@ -130,7 +100,49 @@ def panel(
             panel_type=panel_type,
             panel_id=panel_id,
             institute=institute,
+            maintainer=maintainer,
         )
     except Exception as err:
         LOG.warning(err)
         raise click.Abort()
+
+    return
+
+
+def _panel_omim(adapter, genemap2, mim2genes, api_key, institute, maintainer):
+    """ Add OMIM panel to the database. """
+
+    mim_files = None
+    if genemap2 and mim2genes:
+        mim_files = {
+            "genemap2": list(get_file_handle(genemap2)),
+            "mim2genes": list(get_file_handle(mim2genes)),
+        }
+
+    api_key = api_key or current_app.config.get("OMIM_API_KEY")
+    if not api_key and mim_files is None:
+        LOG.warning("Please provide a omim api key to load the omim gene panel")
+        raise click.Abort()
+    # Check if OMIM-AUTO exists
+    if adapter.gene_panel(panel_id="OMIM-AUTO"):
+        LOG.warning("OMIM-AUTO already exists in database")
+        LOG.info("To create a new version use scout update omim")
+        return
+
+    if not mim_files:
+        try:
+            mim_files = fetch_mim_files(api_key=api_key, genemap2=True, mim2genes=True)
+        except Exception as err:
+            raise err
+
+    # Here we know that there is no panel loaded
+    try:
+        adapter.load_omim_panel(
+            genemap2_lines=mim_files["genemap2"],
+            mim2gene_lines=mim_files["mim2genes"],
+            institute=institute,
+            maintainer=maintainer,
+        )
+    except Exception as err:
+        LOG.error(err)
+        raise click.Abort()
