@@ -100,8 +100,8 @@ def parse_case_data(
     if "owner" not in config_data:
         if not owner:
             raise SyntaxError("Case has no owner")
-        else:
-            config_data["owner"] = owner
+
+        config_data["owner"] = owner
 
     if "gene_panels" in config_data:
         # handle whitespace in gene panel names
@@ -486,6 +486,7 @@ def parse_case(config):
         "case_id": config["family"],
         "display_name": config.get("family_name", config["family"]),
         "genome_build": config.get("human_genome_build"),
+        "lims_id": config.get("lims_id"),
         "rank_model_version": str(config.get("rank_model_version", "")),
         "rank_score_threshold": config.get("rank_score_threshold", 0),
         "sv_rank_model_version": str(config.get("sv_rank_model_version", "")),
