@@ -1,5 +1,9 @@
+import logging
+
 from scout.constants import CALLERS
 
+LOG = logging.getLogger(__name__)
+
 
 def parse_callers(variant, category="snv"):
     """Parse how the different variant callers have performed
@@ -37,4 +41,13 @@ def parse_callers(variant, category="snv"):
             called_by = info.split("|")[0]
             callers[called_by] = "Pass"
 
+    # Assume GATK was used for calling as a default, and report according to vcf FILTER status.
+    if not raw_info or other_info:
+        filter_status = variant.FILTER
+        # cyvcf2 FILTER is None if VCF file column FILTER is "PASS"
+        if filter_status is None:
+            callers["gatk"] = "Pass"
+        else:
+            callers["gatk"] = "Filtered - {}".format(filter_status.replace(";", " - "))
+
     return callers
