@@ -69,6 +69,7 @@ def update_transcripts_information(
         variant_gene(dict): the gene information from the variant
         hgnc_gene(dict): the hgnc gene information
         varaiant_obj(scout.models.Variant)
+        genome_build(str): genome build
 
     """
     genome_build = genome_build or "37"
@@ -181,7 +182,9 @@ def add_gene_info(store, variant_obj, gene_panels=None, genome_build=None):
         panel_info = add_panel_specific_gene_info(extra_info.get(hgnc_id, []))
         variant_gene.update(panel_info)
 
-        update_transcripts_information(variant_gene, hgnc_gene, variant_obj)
+        update_transcripts_information(
+            variant_gene, hgnc_gene, variant_obj, genome_build
+        )
 
         variant_gene["common"] = hgnc_gene
 
@@ -465,11 +468,6 @@ def default_panels(store, case_obj):
     return default_panels
 
 
-def update_hgncsymbol(variant_obj):
-    """Check if the HGNC symbols have changed since the variant was loaded"""
-    pass
-
-
 def clinsig_human(variant_obj):
     """Convert to human readable version of CLINSIG evaluation.
 
