@@ -207,6 +207,9 @@ def add_tx_links(tx_obj, build=37):
     tx_obj["pfam_domain_link"] = pfam(tx_obj.get("pfam_domain"))
     tx_obj["prosite_profile_link"] = prosite(tx_obj.get("prosite_profile"))
     tx_obj["smart_domain_link"] = smart(tx_obj.get("smart_domain"))
+    tx_obj["varsome_link"] = varsome(
+        build, tx_obj.get("refseq_id"), tx_obj.get("coding_sequence_name")
+    )
 
     return tx_obj
 
@@ -266,6 +269,24 @@ def smart(smart_domain):
     return link.format(smart_domain)
 
 
+def varsome(build, refseq_id, protein_sequence_name):
+    """Return a string corresponding to a link to varsome page
+
+    Args:
+        build(str): chromosome build
+        refseq_id(str): transcript refseq id
+        protein_sequence_name(str): transcript sequence name
+
+    """
+
+    if not all([refseq_id, protein_sequence_name]):
+        return None
+
+    link = "https://varsome.com/variant/hg{}/{}:{}"
+
+    return link.format(build, refseq_id, protein_sequence_name)
+
+
 ############# Variant links ####################
 
 
@@ -291,7 +312,7 @@ def get_variant_links(variant_obj, build=None):
         cosmic_link=cosmic_link(variant_obj),
         beacon_link=beacon_link(variant_obj, build),
         ucsc_link=ucsc_link(variant_obj, build),
-        alamut_link=alamut_link(variant_obj),
+        alamut_link=alamut_link(variant_obj, build),
         spidex_human=spidex_human(variant_obj),
     )
     return links
@@ -369,8 +390,8 @@ def cosmic_link(variant_obj):
 
     if not cosmic_ids:
         return None
-    else:
-        cosmic_id = str(cosmic_ids[0])
+
+    cosmic_id = str(cosmic_ids[0])
 
     if cosmic_id.startswith("COS"):
         url_template = "https://cancer.sanger.ac.uk/cosmic/search?q={}"
@@ -415,21 +436,28 @@ def ucsc_link(variant_obj, build=None):
     return url_template.format(this=variant_obj)
 
 
-def alamut_link(variant_obj):
+def alamut_link(variant_obj, build=None):
+    build = build or 37
+
+    build_str = ""
+    if build == 38:
+        build_str = "(GRCh38)"
+
     url_template = (
-        "http://localhost:10000/show?request={this[chromosome]}:"
+        "http://localhost:10000/show?request={this[chromosome]}{build_str}:"
         "{this[position]}{this[reference]}>{this[alternative]}"
     )
-    return url_template.format(this=variant_obj)
+
+    return url_template.format(this=variant_obj, build_str=build_str)
 
 
 def spidex_human(variant_obj):
     """Translate SPIDEX annotation to human readable string."""
     if variant_obj.get("spidex") is None:
         return "not_reported"
-    elif abs(variant_obj["spidex"]) < SPIDEX_HUMAN["low"]["pos"][1]:
+    if abs(variant_obj["spidex"]) < SPIDEX_HUMAN["low"]["pos"][1]:
         return "low"
-    elif abs(variant_obj["spidex"]) < SPIDEX_HUMAN["medium"]["pos"][1]:
+    if abs(variant_obj["spidex"]) < SPIDEX_HUMAN["medium"]["pos"][1]:
         return "medium"
-    else:
-        return "high"
+
+    return "high"
