@@ -5,7 +5,7 @@ import pymongo
 import logging
 from pprint import pprint as pp
 
-from scout.constants import INDEXES
+from scout.constants import INDEXES, REV_ACMG_MAP
 from scout.exceptions import IntegrityError
 
 logger = logging.getLogger(__name__)
@@ -509,7 +509,7 @@ def test_update_case_rerun_status(adapter, case_obj, institute_obj, user_obj):
     adapter.request_rerun(institute_obj, res, user_obj, "blank")
     res = adapter.case(case_obj["_id"])
     # THEN rerun_requested is flagged
-    assert res["rerun_requested"] == True
+    assert res["rerun_requested"] is True
     # Make sure case is still archived
     assert res["status"] == "archived"
 
@@ -643,3 +643,279 @@ def test_get_cases_solved_since(
     # WHEN querying for cases solved within 1 day
     # THEN one case is found
     assert len([case for case in adapter.cases(finished=True, within_days=1)]) == 1
+
+
+def test_keep_manual_rank_tag_after_reupload(
+    adapter, case_obj, variant_obj, user_obj, institute_obj
+):
+    """Test the code that updates custom tags (manual_rank) of new variants according to the old."""
+
+    old_variant = copy.deepcopy(variant_obj)
+    old_variant["_id"] = "old_id"
+
+    ## GIVEN a database with a user
+    adapter.user_collection.insert_one(user_obj)
+
+    ## AND a case
+    adapter.case_collection.insert_one(case_obj)
+
+    ## WHEN the variant is manual ranked
+    adapter.variant_collection.insert_one(old_variant)
+    updated_old = adapter.update_manual_rank(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        link="variant_link",
+        variant=old_variant,
+        manual_rank=8,
+    )
+    assert updated_old
+
+    # THEN replaced by a new variant
+    adapter.variant_collection.delete_one(old_variant)
+
+    new_variant = variant_obj
+    new_variant["_id"] = "new_id"
+    adapter.variant_collection.insert_one(new_variant)
+
+    # THE update actions function should return the id of the new variant
+    updated_new_vars = adapter.update_variant_actions(
+        institute_obj=institute_obj, case_obj=case_obj, old_eval_variants=[updated_old],
+    )
+    assert updated_new_vars["manual_rank"] == ["new_id"]
+
+    # and the new variant should have a the same manual rank
+    test_variant = adapter.variant_collection.find_one({"_id": "new_id"})
+    assert test_variant["manual_rank"] == 8
+
+
+def test_keep_dismiss_variant_tag_after_reupload(
+    adapter, case_obj, variant_obj, user_obj, institute_obj
+):
+    """Test the code that updates custom tags (dismiss_variant) of new variants according to the old."""
+
+    old_variant = copy.deepcopy(variant_obj)
+    old_variant["_id"] = "old_id"
+
+    ## GIVEN a database with a user
+    adapter.user_collection.insert_one(user_obj)
+
+    ## AND a case
+    adapter.case_collection.insert_one(case_obj)
+
+    ## WHEN the variant is manual dismissed
+    adapter.variant_collection.insert_one(old_variant)
+    updated_old = adapter.update_dismiss_variant(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        link="variant_link",
+        variant=old_variant,
+        dismiss_variant=[2, 11],  # provide 2 dismiss reasons
+    )
+    assert updated_old
+
+    # THEN replaced by a new variant
+    adapter.variant_collection.delete_one(old_variant)
+
+    new_variant = variant_obj
+    new_variant["_id"] = "new_id"
+    adapter.variant_collection.insert_one(new_variant)
+
+    # THE update actions function should return the id of the new variant
+    updated_new_vars = adapter.update_variant_actions(
+        institute_obj=institute_obj, case_obj=case_obj, old_eval_variants=[updated_old],
+    )
+    assert updated_new_vars["dismiss_variant"] == ["new_id"]
+
+    # and the new variant should have a the same dismiss_variant
+    test_variant = adapter.variant_collection.find_one({"_id": "new_id"})
+    assert test_variant["dismiss_variant"] == [2, 11]
+
+
+def test_keep_mosaic_tags_after_reupload(
+    adapter, case_obj, variant_obj, user_obj, institute_obj
+):
+    """Test the code that updates custom tags (mosaic tags) of new variants according to the old."""
+
+    old_variant = copy.deepcopy(variant_obj)
+    old_variant["_id"] = "old_id"
+
+    ## GIVEN a database with a user
+    adapter.user_collection.insert_one(user_obj)
+
+    ## AND a case
+    adapter.case_collection.insert_one(case_obj)
+
+    ## WHEN mosaic tag(s) are assigned to the variant
+    adapter.variant_collection.insert_one(old_variant)
+    updated_old = adapter.update_mosaic_tags(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        link="variant_link",
+        variant=old_variant,
+        mosaic_tags=[1, 3],  # provide 2 mosaic tags
+    )
+    assert updated_old
+
+    # THEN the variant is replaced by a new variant
+    adapter.variant_collection.delete_one(old_variant)
+
+    new_variant = variant_obj
+    new_variant["_id"] = "new_id"
+    adapter.variant_collection.insert_one(new_variant)
+
+    # THE update actions function should return the id of the new variant
+    updated_new_vars = adapter.update_variant_actions(
+        institute_obj=institute_obj, case_obj=case_obj, old_eval_variants=[updated_old],
+    )
+    assert updated_new_vars["mosaic_tags"] == ["new_id"]
+
+    # and the new variant should have a the same mosaic tags
+    test_variant = adapter.variant_collection.find_one({"_id": "new_id"})
+    assert test_variant["mosaic_tags"] == [1, 3]
+
+
+def test_keep_cancer_tier_after_reupload(
+    adapter, case_obj, variant_obj, user_obj, institute_obj
+):
+    """Test the code that updates cancer tier of new variants according to the old."""
+
+    old_variant = copy.deepcopy(variant_obj)
+    old_variant["_id"] = "old_id"
+
+    ## GIVEN a database with a user
+    adapter.user_collection.insert_one(user_obj)
+
+    ## AND a case
+    adapter.case_collection.insert_one(case_obj)
+
+    ## WHEN cancer tier is assigned to the variant
+    adapter.variant_collection.insert_one(old_variant)
+    updated_old = adapter.update_cancer_tier(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        link="variant_link",
+        variant=old_variant,
+        cancer_tier="2C",
+    )
+    assert updated_old
+
+    # THEN the variant is replaced by a new variant
+    adapter.variant_collection.delete_one(old_variant)
+
+    new_variant = variant_obj
+    new_variant["_id"] = "new_id"
+    adapter.variant_collection.insert_one(new_variant)
+
+    # THE update actions function should return the id of the new variant
+    updated_new_vars = adapter.update_variant_actions(
+        institute_obj=institute_obj, case_obj=case_obj, old_eval_variants=[updated_old],
+    )
+    assert updated_new_vars["cancer_tier"] == ["new_id"]
+
+    # and the new variant should have a the same mosaic tags
+    test_variant = adapter.variant_collection.find_one({"_id": "new_id"})
+    assert test_variant["cancer_tier"] == "2C"
+
+
+def test_keep_manual_acmg_after_reupload(
+    adapter, case_obj, variant_obj, user_obj, institute_obj
+):
+    """Test the code that updates acmg classification of new variants according to the old."""
+
+    old_variant = copy.deepcopy(variant_obj)
+    old_variant["_id"] = "old_id"
+
+    ## GIVEN a database with a user
+    adapter.user_collection.insert_one(user_obj)
+
+    ## AND a case
+    adapter.case_collection.insert_one(case_obj)
+
+    ## WHEN manual acmg is assigned to the variant
+    adapter.variant_collection.insert_one(old_variant)
+    updated_old = adapter.update_acmg(
+        institute_obj=institute_obj,
+        case_obj=case_obj,
+        user_obj=user_obj,
+        link="variant_link",
+        variant_obj=old_variant,
+        acmg_str="likely_pathogenic",
+    )
+    assert updated_old
+
+    # THEN the variant is replaced by a new variant
+    adapter.variant_collection.delete_one(old_variant)
+
+    new_variant = variant_obj
+    new_variant["_id"] = "new_id"
+    adapter.variant_collection.insert_one(new_variant)
+
+    # THE update actions function should return the id of the new variant
+    updated_new_vars = adapter.update_variant_actions(
+        institute_obj=institute_obj, case_obj=case_obj, old_eval_variants=[updated_old],
+    )
+    assert updated_new_vars["acmg_classification"] == ["new_id"]
+
+    # and the new variant should have a the same classification
+    test_variant = adapter.variant_collection.find_one({"_id": "new_id"})
+    assert test_variant["acmg_classification"] == REV_ACMG_MAP["likely_pathogenic"]
+
+
+def test_keep_variant_comments_after_reupload(
+    adapter, case_obj, variant_obj, user_obj, institute_obj
+):
+    """Test the code that updates comments of new variants according to the old."""
+
+    old_variant = copy.deepcopy(variant_obj)
+    old_variant["_id"] = "old_id"
+    old_variant["is_commented"] = True
+
+    ## GIVEN a database with a user
+    adapter.user_collection.insert_one(user_obj)
+
+    ## AND a case
+    adapter.case_collection.insert_one(case_obj)
+
+    # AND a variant with local comment
+    adapter.comment(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        link="variant_link",
+        variant=old_variant,
+        content="Hello, locally",
+        comment_level="specific",
+    )
+
+    # and a global comment
+    adapter.comment(
+        institute=institute_obj,
+        case=case_obj,
+        user=user_obj,
+        link="variant_link",
+        variant=old_variant,
+        content="Hello, globally",
+        comment_level="global",
+    )
+    assert sum(1 for i in adapter.event_collection.find()) == 2
+
+    # WHEN the variant is re-uploaded
+    adapter.variant_collection.delete_one(old_variant)
+
+    new_variant = variant_obj
+    new_variant["_id"] = "new_id"
+    adapter.variant_collection.insert_one(new_variant)
+
+    # THE update actions function should return the id of the new variant
+    updated_new_vars = adapter.update_variant_actions(
+        institute_obj=institute_obj, case_obj=case_obj, old_eval_variants=[old_variant],
+    )
+
+    assert updated_new_vars["is_commented"] == [new_variant["_id"]]
+
+    # and 2 new comments should be created in the database
+    assert sum(1 for i in adapter.event_collection.find()) == 4
