@@ -866,9 +866,7 @@ def one_variant(request, variant_clinical_file):
     LOG.info("Return one parsed variant")
     variant_parser = VCF(variant_clinical_file)
 
-    for variant in variant_parser:
-        break
-
+    variant = next(variant_parser)
     return variant
 
 
@@ -877,9 +875,7 @@ def one_vep97_annotated_variant(request, vep_97_annotated_variant_clinical_file)
     LOG.info("Return one parsed variant")
     variant_parser = VCF(vep_97_annotated_variant_clinical_file)
 
-    for variant in variant_parser:
-        break
-
+    variant = next(variant_parser)
     return variant
 
 
@@ -888,9 +884,7 @@ def one_cancer_manta_SV_variant(request, vep_94_manta_annotated_SV_variants_file
     LOG.info("Return one parsed cancer SV variant")
     variant_parser = VCF(vep_94_manta_annotated_SV_variants_file)
 
-    for variant in variant_parser:
-        break
-
+    variant = next(variant_parser)
     return variant
 
 
@@ -899,9 +893,7 @@ def one_variant_customannotation(request, customannotation_snv_file):
     LOG.info("Return one parsed variant with custom annotations")
     variant_parser = VCF(customannotation_snv_file)
 
-    for variant in variant_parser:
-        break
-
+    variant = next(variant_parser)
     return variant
 
 
@@ -910,9 +902,7 @@ def one_sv_variant(request, sv_clinical_file):
     LOG.info("Return one parsed SV variant")
     variant_parser = VCF(sv_clinical_file)
 
-    for variant in variant_parser:
-        break
-
+    variant = next(variant_parser)
     return variant
 
 
@@ -921,9 +911,7 @@ def one_str_variant(request, str_clinical_file):
     LOG.info("Return one parsed STR variant")
     variant_parser = VCF(str_clinical_file)
 
-    for variant in variant_parser:
-        break
-
+    variant = next(variant_parser)
     return variant
 
 
