@@ -62,6 +62,16 @@ def test_parse_case_owner(scout_config):
     assert case_data["owner"] == scout_config["owner"]
 
 
+def test_parse_case_limsid(scout_config):
+    """Test parsing a case with lims_id"""
+
+    # GIVEN you load sample information from a scout config
+    # WHEN case is parsed
+    case_data = parse_case(scout_config)
+    # THEN the lims ID should be the same as in config
+    assert case_data["lims_id"] == scout_config["lims_id"]
+
+
 def test_parse_case(scout_config):
     # GIVEN you load sample information from a scout config
     # WHEN case is parsed
